@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -14,7 +14,6 @@
 #if !defined(SLEPC_NLEIGS_H)
 #define SLEPC_NLEIGS_H
 
-
 #define  LBPOINTS  100   /* default value of the maximum number of Leja-Bagby points */
 #define  NDPOINTS  1e4   /* number of discretization points */
 
@@ -51,7 +50,7 @@ typedef struct {
   Vec         t;
 } NEP_NLEIGS_MATSHELL;
 
-PETSC_STATIC_INLINE PetscErrorCode NEPNLEIGSSetShifts(NEP nep,PetscInt *nshiftsw)
+static inline PetscErrorCode NEPNLEIGSSetShifts(NEP nep,PetscInt *nshiftsw)
 {
   NEP_NLEIGS *ctx = (NEP_NLEIGS*)nep->data;
 
@@ -60,7 +59,7 @@ PETSC_STATIC_INLINE PetscErrorCode NEPNLEIGSSetShifts(NEP nep,PetscInt *nshiftsw
     ctx->shifts = &nep->target;
     *nshiftsw = 1;
   } else *nshiftsw = ctx->nshifts;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 SLEPC_INTERN PetscErrorCode NEPSetUp_NLEIGS_FullBasis(NEP);
